local constants = require "scripts.constants"
local callCount = require "scripts.CallCount"
local AudioSource = require "scripts.AudioSource"

local execSourceType = GetExecSourceType()	-- 2 = call state
if execSourceType ~= 2 then
	ShowMessage("Unhandled source type for call state script!")
	return
end
local callId = GetExecSourceId()

local callState = GetCallState(callId)
if callState == nil then
	print(string.format("Could not determine state for call %d\n", callId))
	return
end

print(string.format("Call %d state changed to %d\n", callId, callState))

local callUid1Str = GetVariable(constants.Target1CallUidVarName)
local callUid2Str = GetVariable(constants.Target2CallUidVarName)
local callUid3Str = GetVariable(constants.Target3CallUidVarName)
local callUid4Str = GetVariable(constants.Target4CallUidVarName)

print(string.format("Current UIDs: [%s], [%s], [%s], [%s]\n", callUid1Str, callUid2Str, callUid3Str, callUid4Str))

local callUid1 = -1
local callUid2 = -1
local callUid3 = -1
local callUid4 = -1

if callUid1Str ~= "" then
	callUid1 = tonumber(callUid1Str)
end

if callUid2Str ~= "" then
	callUid2 = tonumber(callUid2Str)
end

if callUid3Str ~= "" then
	callUid3 = tonumber(callUid3Str)
end

if callUid4Str ~= "" then
	callUid4 = tonumber(callUid4Str)
end

local targetId

if callId == callUid1 then
	targetId = 1
elseif callId == callUid2 then
	targetId = 2
elseif callId == callUid3 then
	targetId = 3
elseif callId == callUid4 then
	targetId = 4
else
	print(string.format("Call UID %d is not matching any target (current calls: %d, %d, %d, %d)\n", callId, callUid1, callUid2, callUid3, callUid4))
	return
end

if callState == 0 then
	local nonIdleCount = callCount.CountNonIdle()
	print(string.format("Non-idle call count: %d\n", nonIdleCount))
	if nonIdleCount == 0 then
		-- restore default gong button state
		if GetVariable(constants.GongDefaultVarName) == "1" then
			print("Set gong button to default state (down)\n");
			SetButtonDown(constants.BtnGongId, 1)
		else
			print("Set gong button to default state (up)\n");
			SetButtonDown(constants.BtnGongId, 0)
		end		
	end
elseif callState == 6 then
	if GetButtonDown(constants.BtnGongId) == 1 then
		print("Call %d: default gong (gong btn down)\n", callId);
		SwitchAudioSource2(callId, "aufile", "gong.wav")	
	else
		AudioSource.updateCall(callId)
	end
end

-- very ugly: delay to avoid momentary "CSDIP: wyglaszanie" status
local callState = GetCallState(callId)
if callState == 0 then
	print("Pause before updating button status\n")
	Sleep(1000)
end

local buttonStatus = require "scripts.ButtonStatus"
buttonStatus.update(targetId)
